@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 r"""
-This script starts the test procedures for multilayers. Make sure that you are using the correct version of the SpinD-
-dynamics code since multilayers are relatively new (~2019).
+This script starts the test procedures for multilayer. Make sure that you are using the correct version of the SpinD-
+dynamics code since multilayer are relatively new (~2019).
 """
 from tests.test_multilayers.test_precission_withoutdamping.ctestprecisionwithoutdamping import \
     CTestPrecisionWithoutDamping
